@@ -4,7 +4,7 @@ use warnings;
 use 5.010;
 
 # ABSTRACT: easier loading of a project's local libs
-our $VERSION = "1.001";
+our $VERSION = "1.003";
 
 use FindBin qw();
 use Carp qw(carp);
@@ -18,11 +18,15 @@ sub import {
     my $class = shift;
     my @libdirs;
     my @locallibs;
+    my @extra;
     foreach my $d (@_) {
         if ( $d =~ /^local::lib=([\S]+)/ ) {
             push( @libdirs,   $1 );
             push( @locallibs, $1 );
         }
+        elsif ( $d =~ /^extra=([\S]+)/ ) {
+            @extra = split( /[,;]/, $1 );
+        }
         else {
             push( @libdirs, $d );
         }
@@ -30,20 +34,24 @@ sub import {
 
     my @searchdirs = splitdir("$FindBin::Bin");
 
-SEARCH: while (@searchdirs) {
-        foreach my $dir (@libdirs) {
-            unless ( -d catdir( @searchdirs, $dir ) ) {
-                pop(@searchdirs);
-                next SEARCH;
+    unless ($ROOT) {
+    SEARCH: while (@searchdirs) {
+            foreach my $dir (@libdirs) {
+                unless ( -d catdir( @searchdirs, $dir ) ) {
+                    pop(@searchdirs);
+                    next SEARCH;
+                }
             }
+            $ROOT = catdir(@searchdirs);
+            last SEARCH;
         }
-        $ROOT = catdir(@searchdirs);
-        last SEARCH;
     }
 
     if ($ROOT) {
-        local::lib->import( map { catdir( $ROOT, $_ ) } @locallibs ) if @locallibs;
-        lib->import( map        { catdir( $ROOT, $_ ) } @libdirs ) if @libdirs;
+        local::lib->import( map { catdir( $ROOT, $_ ) } @locallibs )
+            if @locallibs;
+        lib->import( map { catdir( $ROOT, $_ ) } @libdirs ) if @libdirs;
+        __PACKAGE__->load_extra(@extra) if @extra;
     }
     else {
         carp "Could not find root dir containing " . join( ', ', @libdirs );
@@ -83,7 +91,7 @@ lib::projectroot - easier loading of a project's local libs
 
 =head1 VERSION
 
-version 1.001
+version 1.003
 
 =head1 SYNOPSIS
 
@@ -106,6 +114,9 @@ version 1.001
   # 'Your-OtherModule/lib' and 'Dark-PAN/lib' to @INC
   lib::projectroot->load_extra(Your-OtherModule Dark-PAN);
 
+  # the same as above
+  use lib::projectroot qw(lib local::lib=local extra=Your-OtherModule,Dark-PAN);
+
 =head1 DESCRIPTION
 
 I'm usually using a setup like this:
@@ -129,7 +140,7 @@ I'm usually using a setup like this:
 
 There is C<AProject>, which is the actual code I'm working on. There
 is also probably C<BProject>, e.g. another microservice for the same
-customer. C<AProject> has it's own code in C<lib> and it's CPAN
+customer. C<AProject> has its own code in C<lib> and its CPAN
 dependencies in C<local> (managed via C<Carton> and used via
 C<local::lib>). There are a bunch of scripts / "binaries" in C<bin>,
 in a lot of different directories of varying depth.
@@ -158,6 +169,14 @@ to get my other code pushed to C<@INC>. (Though currently I put this
 line, and some other setup code like initialising C<Log::Any> into
 C<AProject::Run>, and just C<use AProject::Run;>)
 
+You can also define extra dists directly while loading C<lib::projectroot>:
+
+  use lib::projectroot qw(
+      lib
+      local::lib=local
+      extra=MyHelperStuff,CoolLib-NotYetOnCPAN
+  );
+
 =head1 TODOs
 
 Some ideas for future releases:
@@ -166,9 +185,7 @@ Some ideas for future releases:
 
 =item * what happens if C<$PERL5LIB> is already set?
 
-=item * add C<local::lib> dirs of extras (i.e. if DarkPAN also uses C<local::lib> to install it's deps)
-
-=item * also load extras via C<lib::projectroot>'s C<import> method
+=item * add C<local::lib> dirs of extras (i.e. if DarkPAN also uses C<local::lib> to install its deps)
 
 =item * think about the security issues raised by Abraxxa (http://prepan.org/module/nY4oajhgzJN 2014-12-02 18:42:07)
 
